@@ -24,9 +24,11 @@
 #include "session_p.h"
 #include "rfccodecs.h"
 
+#include <KLocalizedString>
+
 //TODO: when custom error codes are introduced, handle the NO [TRYCREATE] response
 
-namespace KIMAP2
+namespace KIMAP
 {
 class MoveJobPrivate : public JobPrivate
 {
@@ -46,10 +48,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 MoveJob::MoveJob(Session *session)
-    : Job(*new MoveJobPrivate(session, "Move"))
+    : Job(*new MoveJobPrivate(session, i18n("Move")))
 {
     Q_D(MoveJob);
     d->uidBased = false;
@@ -106,14 +108,14 @@ void MoveJob::doStart()
     Q_D(MoveJob);
 
     QByteArray parameters = d->set.toImapSequenceSet() + ' ';
-    parameters += '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"';
+    parameters += '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"';
 
     QByteArray command = "MOVE";
     if (d->uidBased) {
         command = "UID " + command;
     }
 
-    d->sendCommand(command, parameters);
+    d->tags << d->sessionInternal()->sendCommand(command, parameters);
 }
 
 void MoveJob::handleResponse(const Message &response)
